.. include:: ../../README.rst

**User guide**

* :doc:`examples`

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: User guide

   examples

**Reference**

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Reference:

   api
   install



Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
